@@ -56,7 +56,7 @@ class EventSubType(Enum):
     STATE = 'state'
     CONFIG = 'config'
     PARENT = 'parent'
-    PLATFORM = 'platform'
+    PROVIDER = 'platform'
 
 
 class EventState(Enum):
@@ -66,10 +66,10 @@ class EventState(Enum):
     DELETED = 'deleted'
 
 
-class EventPlatform(Enum):
+class EventProvider(Enum):
     OPENSTACK = 'openstack'
-    VSPHERE = 'vsphere'
     VCLOUD = 'vcloud'
+    VSPHERE = 'vsphere'
     NUTANIX = 'nutanix'
     OPENSHIFT = 'openshift'
     KUBERNETES = 'kubernetes'
